<?php

namespace Drupal\nats;

use Drupal\Core\Site\Settings;

/**
 * NATS client factory.
 */
class NatsClientFactory {

  /**
   * Create NATS client with configuration for `$name`.
   */
  public function get(string $name) {
    $settings = $this->getClientSettings($name);
    if (!$settings) {
      throw new \Exception("NATS client '{$name}' is not configured in settings.php");
    }

    return new WrappedNatsClient($name, $settings);
  }

  /**
   * Get client settings from settings.php.
   */
  protected function getClientSettings(string $name) {
    $settings = Settings::get('nats');
    if (!$settings) {
      return NULL;
    }

    // Check existence of client settings.
    if (!array_key_exists($name, $settings)) {
      return NULL;
    }

    $clientSettings = $settings[$name];
    if (!is_array($clientSettings)) {
      return NULL;
    }

    return array_merge($this->getDefaultSettings(), $clientSettings);
  }

  /**
   * Default client settings.
   */
  protected function getDefaultSettings(): array {
    return [
      'jwt' => NULL,
      'pass' => NULL,
      'lang' => 'php',
      'port' => 4222,
      'reconnect' => TRUE,
      'timeout' => 1,
      'pedantic' => FALSE,
      'token' => NULL,
      'user' => NULL,
      'nkey' => NULL,
      'verbose' => FALSE,
      'version' => 'dev',
    ];
  }

}
