<?php

namespace Drupal\nats;

use Basis\Nats\Client;
use Symfony\Component\DependencyInjection\Attribute\AutoconfigureTag;

/**
 * NATS client manager.
 */
#[AutoconfigureTag('service_collector', [
  'tag' => 'nats_client',
  'call' => 'addClient',
])]
class NatsClientManager implements NatsClientManagerInterface {

  /**
   * Array of registered clients.
   *
   * @var WrappedNatsClientInterface[]
   */
  protected $clients = [];

  /**
   * Add client in manager.
   */
  public function addClient(WrappedNatsClientInterface $client): void {
    $this->clients[$client->getName()] = $client;
  }

  /**
   * Get client by optional name.
   *
   * Returns default client if specific one not found,
   * or not specified.
   */
  public function get(string $name = 'default'): ?Client {
    foreach ($this->clients as $wrappedClient) {
      if ($wrappedClient->getName() === $name) {
        return $wrappedClient->getClient();
      }
    }

    if (isset($this->clients['default'])) {
      return $this->clients['default']->getClient();
    }

    return NULL;
  }

  /**
   * Check connection to each registered client.
   */
  public function checkHealth(): array {
    $status = [];

    foreach ($this->clients as $wrappedClient) {
      $client = $wrappedClient->getClient();

      try {
        $result = $client->ping();
        $status[$wrappedClient->getName()] = $result;
      }
      catch (\Exception) {
        $status[$wrappedClient->getName()] = FALSE;
      }
    }

    return $status;
  }

}
